Kudos
=====

This project started as a port of `django-push-notifications`_ with the goal of just separating the APNS and GCM modules from the Django related items. However, the implementation details, internals, and API interface have changed in ``pushjack`` and is no longer compatible with `django-push-notifications`_. But a special thanks goes out to the author and contributors of `django-push-notifications`_ who unknowingly helped start this project along.


.. _django-push-notifications: https://github.com/jleclanche/django-push-notifications
